==> gurux.dlms-4.0.61-sources.jar: gurux/dlms/objects/enums/DataProtectionKeyType.java <==
//
// --------------------------------------------------------------------------
//  Gurux Ltd
// 
//
//
// Filename:        $HeadURL$
//
// Version:         $Revision$,
//                  $Date$
//                  $Author$
//
// Copyright (c) Gurux Ltd
//
//---------------------------------------------------------------------------
//
//  DESCRIPTION
//
// This file is a part of Gurux Device Framework.
//
// Gurux Device Framework is Open Source software; you can redistribute it
// and/or modify it under the terms of the GNU General Public License 
// as published by the Free Software Foundation; version 2 of the License.
// Gurux Device Framework is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of 
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
// See the GNU General Public License for more details.
//
// More information of Gurux products: https://www.gurux.org
//
// This code is licensed under the GNU General Public License v2. 
// Full text may be retrieved at http://www.gnu.org/licenses/gpl-2.0.txt
//---------------------------------------------------------------------------

package gurux.dlms.objects.enums;

import java.util.HashMap;
/**
 *  Enumerates data protection key types.
 */
public enum DataProtectionKeyType
{
    /** 
     Identified key.
    */
    IDENTIFIED,
    /** 
     Wrapped key.
    */
    WRAPPED,
    /** 
     Agreed.
    */
    AGREED;

    public int getValue()
    {
        return this.ordinal();
    }

    public static DataProtectionKeyType forValue(int value)
    {
        return values()[value];
    }
}

==> gurux.dlms-4.0.70-sources.jar: gurux/dlms/objects/enums/DataProtectionKeyType.java <==
//
// --------------------------------------------------------------------------
//  Gurux Ltd
// 
//
//
// Filename:        $HeadURL$
//
// Version:         $Revision$,
//                  $Date$
//                  $Author$
//
// Copyright (c) Gurux Ltd
//
//---------------------------------------------------------------------------
//
//  DESCRIPTION
//
// This file is a part of Gurux Device Framework.
//
// Gurux Device Framework is Open Source software; you can redistribute it
// and/or modify it under the terms of the GNU General Public License 
// as published by the Free Software Foundation; version 2 of the License.
// Gurux Device Framework is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of 
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
// See the GNU General Public License for more details.
//
// More information of Gurux products: https://www.gurux.org
//
// This code is licensed under the GNU General Public License v2. 
// Full text may be retrieved at http://www.gnu.org/licenses/gpl-2.0.txt
//---------------------------------------------------------------------------

package gurux.dlms.objects.enums;

/**
 * Enumerates data protection key types.
 */
public enum DataProtectionKeyType {
    /**
     * Identified key.
     */
    IDENTIFIED,
    /**
     * Wrapped key.
     */
    WRAPPED,
    /**
     * Agreed.
     */
    AGREED;

    public int getValue() {
        return this.ordinal();
    }

    public static DataProtectionKeyType forValue(int value) {
        return values()[value];
    }
}
